// Copyright (c) 2023, the Dart project authors.  Please see the AUTHORS file
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.

extension DateTimeExtension on DateTime {
  DateTime roundDownToSeconds() => DateTime.fromMillisecondsSinceEpoch(
    millisecondsSinceEpoch -
        millisecondsSinceEpoch % const Duration(seconds: 1).inMilliseconds,
  );
}
